@@ -3,11 +3,17 @@
 #[cfg(not(any(feature = "tokio", feature = "async-std")))]
 compile_error!("Either feature \"tokio\" or \"async-std\" must be enabled for unrar-async.");
 
+#[cfg(feature = "tokio")]
+extern crate runtime_tokio as tokio;
+#[cfg(feature = "async-std")]
+extern crate runtime_async_std as async_std;
+
 use std::borrow::Cow;
 use std::ffi::CString;
 use std::path::Path;
 use std::path::PathBuf;
 
+use tracing::instrument;
 use widestring::WideCString;
 
 pub mod error;
@@ -34,6 +40,7 @@ pub struct Archive<'a> {
 
 impl<'a> Archive<'a> {
 	/// Creates an `Archive` object to operate on a plain RAR archive
+	#[instrument(err, level = "info", skip(file), fields(archive.file = %file.as_ref().display()))]
 	pub fn new<F>(file: &'a F) -> Result<Self, Error>
 	where
 		F: AsRef<Path> + ?Sized
@@ -47,6 +54,7 @@ impl<'a> Archive<'a> {
 	}
 
 	/// Creates an `Archive` object to operate on a password-encrypted RAR archive.
+	#[instrument(err, level = "debug", skip(file, password), fields(archive.file = %file.as_ref().display()))]
 	pub fn with_password<F, P>(file: &'a F, password: &'a P) -> Result<Self, Error>
 	where
 		F: AsRef<Path> + ?Sized,
@@ -136,21 +144,25 @@ impl<'a> Archive<'a> {
 	}
 
 	/// Opens the underlying archive for listing its contents
+	#[instrument(err, level = "info", skip(self), fields(archive.file = %self.filename.as_ref().display()))]
 	pub async fn list(self) -> Result<OpenArchive, Error> {
 		self.open(OpenMode::List, None, Operation::Skip).await
 	}
 
 	/// Opens the underlying archive for listing its contents without omitting or pooling split entries
+	#[instrument(err, level = "info", skip(self), fields(archive.file = %self.filename.as_ref().display()))]
 	pub async fn list_split(self) -> Result<OpenArchive, Error> {
 		self.open(OpenMode::ListSplit, None, Operation::Skip).await
 	}
 
 	/// Opens the underlying archive for extracting to the given directory
+	#[instrument(err, level = "info", skip(self, path), fields(archive.file = %self.filename.as_ref().display(), target = %path.as_ref().display()))]
 	pub async fn extract_to(self, path: impl AsRef<Path>) -> Result<OpenArchive, Error> {
 		self.open(OpenMode::Extract, Some(path.as_ref()), Operation::Extract).await
 	}
 
 	/// Opens the underlying archive for testing
+	#[instrument(err, level = "info", skip(self), fields(archive.file = %self.filename.as_ref().display()))]
 	pub async fn test(self) -> Result<OpenArchive, Error> {
 		self.open(OpenMode::Extract, None, Operation::Test).await
 	}
